# Roadmap

**Stand 26.07.2021**

Die FIT-Connect Submission API, die Routing API und die dazugehörige Infrastruktur wird in einem Projekt des IT-Planungsrats im Jahr
2021 zu einer Produktreife entwickelt. Die Umsetzung der Projektliefergegenstände erfolgt iterativ, um eine schnelle
Erprobung und Feedback zu ermöglichen.

Die Roadmap soll daher einen Überblick verschaffen, wann das FIT-Connect Team für die folgenden Projektliefergegenstände
neue Features anstrebt:

- **API-Spezifikation:** In der OpenAPI geschriebene Spezifikation der FIT-Connect Submission API.
- **Entwicklerdokumentation- und tools:** Weiterführende Dokumentationsartikel zur technischen Anbindung an der API für
  sendende und empfangende Systeme udn Bereitstellung von Tools für technische Querschnittsaufgaben wie Tokenhandling,
  Signaturprüfung oder Verschlüsselung.
- **Infrastruktur:** Bereitstellung von Infrastrukturkomponenten für die Durchführung von Anbindungstests oder
  Validierungsaufgaben sowie die produktive Bereitstellung der API für Datenübermittlungen.

Die Roadmap wird laufend aktualisiert und erweitert. Unser Team versucht weitestgehend verbindliche Termine zu benennen,
jedoch passen wir die Umsetzungen den aktuellen Bedarfen des Projekts an, wodurch es zu Verzögerungen bei manchen
Liefergegenständen kommen kann. Umgekehrt kann es auch sein, das Features früher fertiggestellt werden, falls die
Prioritäten ändern oder freie Kapazitäten zur Verfügung stehen.

Wir nehmen gerne neue Wünsche & Anregungen für die FIT-Connect APIs als Issue auf unserem
Projekt (https://git.fitko.de/fit-connect/api) entgegen und versuche diese Issues nach einer Umsetzungsprüfung in unsere
Roadmap aufzunehmen.

> Wünsche & Anregungen oder Fehler können über den [hier](/#found-bug) beschriebenen Prozess abgegeben werden können.

## Überblick über die Zeitplanung

- **Seit 24.06.2021:** Preview der API-Spezifikation und der Entwicklerdokumentaion für die Version 1.0 der Submission API ist
  online und ist für alle interessierten Entwickler zugänglich.
- **Anfang August 2021:** Bis zu diesem Zeitpunkt werden alle Kernfeatures der Submission API spezifiziert und als stabile API
  Spezifikation veröffentlicht. Für die Evaluierung und Entwicklung durch interessierte Entwickler wird ein öffentlicher
  Testserver bereitgestellt.
- **Bis September 2021:** Die Submission API wird als Produktivinfrastruktur für erste Pilotantragsverfahren und deren Systeme
  bereitstellt. Zudem werden noch neue abwärtskompatible Features und zusätzliche Entwicklerangebote bereitgestellt.
- **Bis Q2 2022:** Alle Beschlüsse zur weiteren Pflege der API und dem Betrieb der Infrastruktur liegen vor.

## Detailplanung bis Mitte August 2021

### API-Spezifikation

Die Submission API wird mit folgenden Änderungen und Erweiterung in der Form einer V1 finalisiert:
- **Bereitstellung und Übermittlung des Security Event Logs:** Der bisherige Übermittlungsstatus wird durch einen
  Security Event Log ersetzt, der aus signierten Security Event Tokens besteht und die einzelnen Übermittlungsschritte
  beweissicher dokumentiert. Die jeweiligen Security Event Tokens sind durch die jeweils verantwortlichen Systeme (
  Zustelldienst bzw. das empfangende System) zu erstellen und zu signieren. Dieser Security Event Log kann über die API
  von beiden Parteien abgerufen werden und dient späteren Nachweisen über die korrekte Zustellung.
- **Callbacks zur Benachrichtigung sendender Systeme:** Sendende Systeme bekommen die Möglichkeit für Submissions einen
  Callback einzurichten. Über diesen Callback informiert der Zustelldienst sendende Systeme, sobald es Änderungen im
  Zustellstatus. Durch den Callback soll ein regelmäßiges Polling des Security Event Log zur Prüfung des Zustellstatus
  unnötig gemacht werden.
- **Neuumsetzung von Features:** Einige Features aus der Beta7 Version der API wie die Abfrage von Destination
  Informationen und die Abfrage von abholbereiten Anträgen werden neu konzipiert und sind in der aktuellen Preview noch
  nicht enthalten.
- **Neues Client Autorisierungskonzept auf Basis des bestehen Client Credentials Flows:** Ein neues OAuth Konzept soll
  umgesetzt werden, da detailierte Berechtigung für den API-Zugriff ermöglicht und höhere Sicherheit für die Nutzung von
  Access Token gewährleistet.
- **Anlegen neuer Zustellpunkte nur über das Self-Service-Portal:** Aufgrund des neuen Autorisierungskonzepts werden neue Zustellpunkte aktuell nur noch über das Self-Service-Portal angelegt. Änderungen an Zustellpunkten (bspw. Hinterlegung von Zertifikaten oder Fachschemareferenzen) werden weiterhin über die API möglich sein.

### Entwicklerdokumentation- und tools

### Infrastruktur

- **Testinfrastruktur:** Es wird eine Testinfrastruktur bereitgestellt, über die alle Funktionen der API angesprochen
  und getestet werden können.
- **Self-Service-Portal:** Es wird ein Self-Service-Portal eingerichtet, über das Entwickler ihre API-Clients am OAuth
  Server selbst anlegen können. Als weiteres Feature wird es für Betreiber von empfangenden Systemen möglich sein, über
  das Self-Service-Portal Destinations anzulegen und zu konfigurieren. Das Self-Service-Portal wird mit dem Start des Testserver bereitgestellt.

## Detailplanung bis September 2021

### API-Spezifikation

- Im Rahmen der Produktivstellungen werden Erweiterungen an der API zurückgestellt und nur bei dringenden Bedarf bzw.
  kritischen Fehlern Fixes an der API durchgeführt.

### Entwicklerdokumentation- und tools

- **Bereitstellung von SDKs für erste Querschnittsfunktionen:** Es ist geplant, erste Unterstützungsfunktionen für
  Querschnittsaufgaben bereitzustellen.

### Infrastruktur

- **Sandbox Systeme**: Über eine Portaloberfläche werden generische API-Clients angeboten, um bei Versand oder Empfang
  von Submissions die jeweilige Gegenseite zu simulieren.

## Detailplanung bis Ende 2021

### API-Spezifikation

- **Routing API:** Über die Routing API wird zukünftig möglich sein, Destinations und deren technische Parameter über
  eine API Anfrage anhand technische Zuständigkeitskriterien zu ermitteln.
- **Hinterlegung einer OSCI-Weiterleitung:** Um bestehende OSCI Intermediärsinfrastrukturen einzubinden, wird eine
  Hinterlegung von OSCI-Kommunikationsparametern möglich sein. Hierdurch werden abgebeben Submissions durch den
  Zustelldienst automatisch an den vorgesehen OSCI Intermediär weitergeleitet.
- **Erweiterung um einen Rückkanal für Prozessstandards:** Als abwärtskompatible Erweiterung wird über die API
  ermöglich, eine bilaterale Antragskommunikation auf Basis von Fachstandards wie XBau umzusetzen. API-Nutzer, die
  FIT-Connect nur für Einreichungen nutzen, sind von diesen Änderungen nicht betroffen.
- **Weiterentwicklung von FIM/XFall Schemata**: Um die Nutzung von FIM für die Antragsübermittlung zu vereinfachen,
  werden in Zusammenarbeit mit FIM neue technologische Ansätze und Verbesserung in der Schema Nutzung angestrebt.

### Entwicklerdokumentation- und tools

- **Vollumfängliche Bereitstellung von SDKs**: In der zweiten Jahreshälfte werden SDKs in verschiedenen
  Programmiersprachen für alle zentralen FIT-Connect Anforderungen angeboten.
- **FIM Entwicklungstools**: Um die Nutzung von FIM für Antragsschemata sollen diverse Entwicklungstools für die
  Generierung und Validierung von FIM/XFall Nachrichten angeboten werden.

### Infrastruktur

- **Validierungsumgebung:** Um gegenüber Auftraggebern oder anderen Stellen nachzuweisen, dass die eigene Software
  FIT-Connect nutzen kann, soll eine Validierungsumgebung geschaffen werden, die die API-Umsetzung gegenüber
  festgelegten Testfällen prüfen und hierfür einen signierten Nachweis an den Verfahrenbetreiber ausstellt.

## Bis Q2 2022

... TBD ...
